Trait rasi_default::TokenSequence
source · pub trait TokenSequence {
// Provided method
fn next() -> Token { ... }
}Expand description
This trait defines a method for sequential generation of tokens
Note: This type is only available on platforms that support atomic loads and stores of usize
Provided Methods
Object Safety
This trait is not object safe.